;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "term-manager" "20260220.840"
  "Contextual terminal management."
  '((dash  "2.12.0")
    (emacs "24.4"))
  :url "https://www.github.com/IvanMalison/term-manager"
  :commit "1581a90ff9b359449e056da55259b9f42e749f0c"
  :revdesc "1581a90ff9b3"
  :keywords '("terminals" "tools")
  :authors '(("Ivan Malison" . "IvanMalison@gmail.com"))
  :maintainers '(("Ivan Malison" . "IvanMalison@gmail.com")))
